"""
Python module generated from Java source file org.bukkit.inventory.meta.SpawnEggMeta

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import EntityType
from org.bukkit.inventory.meta import *
from typing import Any, Callable, Iterable, Tuple


class SpawnEggMeta(ItemMeta):
    """
    Represents a spawn egg and it's spawned type.
    """

    def getSpawnedType(self) -> "EntityType":
        """
        Get the type of entity this egg will spawn.

        Returns
        - The entity type. May be null for implementation specific default.

        Deprecated
        - different types are different items
        """
        ...


    def setSpawnedType(self, type: "EntityType") -> None:
        """
        Set the type of entity this egg will spawn.

        Arguments
        - type: The entity type. May be null for implementation specific
        default.

        Deprecated
        - different types are different items
        """
        ...


    def clone(self) -> "SpawnEggMeta":
        ...



"""
Python module generated from Java source file com.google.common.cache.AbstractLoadingCache

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.cache import *
from com.google.common.collect import ImmutableMap
from com.google.common.collect import Maps
from com.google.common.util.concurrent import UncheckedExecutionException
from java.util.concurrent import Callable
from java.util.concurrent import ExecutionException
from typing import Any, Callable, Iterable, Tuple


class AbstractLoadingCache(AbstractCache, LoadingCache):
    """
    This class provides a skeletal implementation of the `Cache` interface to minimize the
    effort required to implement this interface.
    
    To implement a cache, the programmer needs only to extend this class and provide an
    implementation for the .get(Object) and .getIfPresent methods. .getUnchecked, .get(Object, Callable), and .getAll are implemented in terms of
    `get`; .getAllPresent is implemented in terms of `getIfPresent`; .putAll is implemented in terms of .put, .invalidateAll(Iterable) is implemented
    in terms of .invalidate. The method .cleanUp is a no-op. All other methods throw
    an UnsupportedOperationException.

    Author(s)
    - Charles Fry

    Since
    - 11.0
    """

    def getUnchecked(self, key: "K") -> "V":
        ...


    def getAll(self, keys: Iterable["K"]) -> "ImmutableMap"["K", "V"]:
        ...


    def apply(self, key: "K") -> "V":
        ...


    def refresh(self, key: "K") -> None:
        ...



from .HttpHeaders import HttpHeaders
from .ParametricNullness import ParametricNullness
from .HostAndPort import HostAndPort
from .MediaType import MediaType
from .InternetDomainName import InternetDomainName
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .PercentEscaper import PercentEscaper
from .UrlEscapers import UrlEscapers
from .HostSpecifier import HostSpecifier
from .InetAddresses import InetAddresses


"""
Python module generated from Java source file org.bukkit.entity.Guardian

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Guardian(Monster):

    def setLaser(self, activated: bool) -> bool:
        """
        Sets whether the guardian laser should show or not.
        
        A target must be present. If no target is present the laser will not show
        and the method will return False.

        Arguments
        - activated: whether the laser is active

        Returns
        - True if the laser was activated otherwise False

        See
        - .setTarget(LivingEntity)
        """
        ...


    def hasLaser(self) -> bool:
        """
        Gets whether the guardian laser is active or not.

        Returns
        - True if the laser is active otherwise False
        """
        ...


    def isElder(self) -> bool:
        """
        Check if the Guardian is an elder Guardian

        Returns
        - True if the Guardian is an Elder Guardian, False if not

        Deprecated
        - should check if instance of ElderGuardian.
        """
        ...


    def setElder(self, shouldBeElder: bool) -> None:
        """
        Arguments
        - shouldBeElder: shouldBeElder

        Deprecated
        - Must spawn a new ElderGuardian.
        """
        ...



"""
Python module generated from Java source file com.google.gson.JsonElement

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import Streams
from com.google.gson.stream import JsonWriter
from java.io import IOException
from java.io import StringWriter
from java.math import BigDecimal
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class JsonElement:
    """
    A class representing an element of Json. It could either be a JsonObject, a
    JsonArray, a JsonPrimitive or a JsonNull.

    Author(s)
    - Joel Leitch
    """

    def deepCopy(self) -> "JsonElement":
        """
        Returns a deep copy of this element. Immutable elements like primitives
        and nulls are not copied.

        Since
        - 2.8.2
        """
        ...


    def isJsonArray(self) -> bool:
        """
        provides check for verifying if this element is an array or not.

        Returns
        - True if this element is of type JsonArray, False otherwise.
        """
        ...


    def isJsonObject(self) -> bool:
        """
        provides check for verifying if this element is a Json object or not.

        Returns
        - True if this element is of type JsonObject, False otherwise.
        """
        ...


    def isJsonPrimitive(self) -> bool:
        """
        provides check for verifying if this element is a primitive or not.

        Returns
        - True if this element is of type JsonPrimitive, False otherwise.
        """
        ...


    def isJsonNull(self) -> bool:
        """
        provides check for verifying if this element represents a null value or not.

        Returns
        - True if this element is of type JsonNull, False otherwise.

        Since
        - 1.2
        """
        ...


    def getAsJsonObject(self) -> "JsonObject":
        """
        convenience method to get this element as a JsonObject. If the element is of some
        other type, a IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonObject()
        first.

        Returns
        - get this element as a JsonObject.

        Raises
        - IllegalStateException: if the element is of another type.
        """
        ...


    def getAsJsonArray(self) -> "JsonArray":
        """
        convenience method to get this element as a JsonArray. If the element is of some
        other type, a IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonArray()
        first.

        Returns
        - get this element as a JsonArray.

        Raises
        - IllegalStateException: if the element is of another type.
        """
        ...


    def getAsJsonPrimitive(self) -> "JsonPrimitive":
        """
        convenience method to get this element as a JsonPrimitive. If the element is of some
        other type, a IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonPrimitive()
        first.

        Returns
        - get this element as a JsonPrimitive.

        Raises
        - IllegalStateException: if the element is of another type.
        """
        ...


    def getAsJsonNull(self) -> "JsonNull":
        """
        convenience method to get this element as a JsonNull. If the element is of some
        other type, a IllegalStateException will result. Hence it is best to use this method
        after ensuring that this element is of the desired type by calling .isJsonNull()
        first.

        Returns
        - get this element as a JsonNull.

        Raises
        - IllegalStateException: if the element is of another type.

        Since
        - 1.2
        """
        ...


    def getAsBoolean(self) -> bool:
        """
        convenience method to get this element as a boolean value.

        Returns
        - get this element as a primitive boolean value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        boolean value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsNumber(self) -> "Number":
        """
        convenience method to get this element as a Number.

        Returns
        - get this element as a Number.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        number.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsString(self) -> str:
        """
        convenience method to get this element as a string value.

        Returns
        - get this element as a string value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        string value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsDouble(self) -> float:
        """
        convenience method to get this element as a primitive double value.

        Returns
        - get this element as a primitive double value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        double value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsFloat(self) -> float:
        """
        convenience method to get this element as a primitive float value.

        Returns
        - get this element as a primitive float value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        float value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsLong(self) -> int:
        """
        convenience method to get this element as a primitive long value.

        Returns
        - get this element as a primitive long value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        long value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsInt(self) -> int:
        """
        convenience method to get this element as a primitive integer value.

        Returns
        - get this element as a primitive integer value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        integer value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def getAsByte(self) -> int:
        """
        convenience method to get this element as a primitive byte value.

        Returns
        - get this element as a primitive byte value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        byte value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.

        Since
        - 1.3
        """
        ...


    def getAsCharacter(self) -> str:
        """
        convenience method to get the first character of this element as a string or the first
        character of this array's first element as a string.

        Returns
        - the first character of the string.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        string value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.

        Since
        - 1.3

        Deprecated
        - This method is misleading, as it does not get this element as a char but rather as
        a string's first character.
        """
        ...


    def getAsBigDecimal(self) -> "BigDecimal":
        """
        convenience method to get this element as a BigDecimal.

        Returns
        - get this element as a BigDecimal.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive.
        * @throws NumberFormatException if the element is not a valid BigDecimal.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.

        Since
        - 1.2
        """
        ...


    def getAsBigInteger(self) -> "BigInteger":
        """
        convenience method to get this element as a BigInteger.

        Returns
        - get this element as a BigInteger.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive.
        - NumberFormatException: if the element is not a valid BigInteger.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.

        Since
        - 1.2
        """
        ...


    def getAsShort(self) -> int:
        """
        convenience method to get this element as a primitive short value.

        Returns
        - get this element as a primitive short value.

        Raises
        - ClassCastException: if the element is of not a JsonPrimitive and is not a valid
        short value.
        - IllegalStateException: if the element is of the type JsonArray but contains
        more than a single element.
        """
        ...


    def toString(self) -> str:
        """
        Returns a String representation of this element.
        """
        ...



"""
Python module generated from Java source file com.google.common.math.MathPreconditions

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.math import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.math import BigInteger
from java.math import RoundingMode
from typing import Any, Callable, Iterable, Tuple


class MathPreconditions:
    """
    A collection of preconditions for math functions.

    Author(s)
    - Louis Wasserman
    """





"""
Python module generated from Java source file org.bukkit.entity.FishHook

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class FishHook(Projectile):
    """
    Represents a fishing hook.
    """

    def getMinWaitTime(self) -> int:
        """
        Get the minimum number of ticks one has to wait for a fish biting.
        
        The default is 100 ticks (5 seconds).
        Note that this is before applying lure.

        Returns
        - Minimum number of ticks one has to wait for a fish biting
        """
        ...


    def setMinWaitTime(self, minWaitTime: int) -> None:
        """
        Set the minimum number of ticks one has to wait for a fish biting.
        
        The default is 100 ticks (5 seconds).
        Note that this is before applying lure.

        Arguments
        - minWaitTime: Minimum number of ticks one has to wait for a fish
        biting
        """
        ...


    def getMaxWaitTime(self) -> int:
        """
        Get the maximum number of ticks one has to wait for a fish biting.
        
        The default is 600 ticks (30 seconds).
        Note that this is before applying lure.

        Returns
        - Maximum number of ticks one has to wait for a fish biting
        """
        ...


    def setMaxWaitTime(self, maxWaitTime: int) -> None:
        """
        Set the maximum number of ticks one has to wait for a fish biting.
        
        The default is 600 ticks (30 seconds).
        Note that this is before applying lure.

        Arguments
        - maxWaitTime: Maximum number of ticks one has to wait for a fish
        biting
        """
        ...


    def getApplyLure(self) -> bool:
        """
        Get whether the lure enchantment should be applied to reduce the wait
        time.
        
        The default is True.
        Lure reduces the wait time by 100 ticks (5 seconds) for each level of the
        enchantment.

        Returns
        - Whether the lure enchantment should be applied to reduce the wait
        time
        """
        ...


    def setApplyLure(self, applyLure: bool) -> None:
        """
        Set whether the lure enchantment should be applied to reduce the wait
        time.
        
        The default is True.
        Lure reduces the wait time by 100 ticks (5 seconds) for each level of the
        enchantment.

        Arguments
        - applyLure: Whether the lure enchantment should be applied to reduce
        the wait time
        """
        ...


    def getBiteChance(self) -> float:
        """
        Gets the chance of a fish biting.
        
        0.0 = No Chance.
        1.0 = Instant catch.

        Returns
        - chance the bite chance

        Deprecated
        - has no effect in newer Minecraft versions
        """
        ...


    def setBiteChance(self, chance: float) -> None:
        """
        Sets the chance of a fish biting.
        
        0.0 = No Chance.
        1.0 = Instant catch.

        Arguments
        - chance: the bite chance

        Raises
        - IllegalArgumentException: if the bite chance is not between 0
            and 1

        Deprecated
        - has no effect in newer Minecraft versions
        """
        ...


    def isInOpenWater(self) -> bool:
        """
        Check whether or not this fish hook is in open water.
        
        Open water is defined by a 5x4x5 area of water, air and lily pads. If in
        open water, treasure items may be caught.

        Returns
        - True if in open water, False otherwise
        """
        ...


    def getHookedEntity(self) -> "Entity":
        """
        Get the entity hooked by this fish hook.

        Returns
        - the hooked entity. null if none
        """
        ...


    def setHookedEntity(self, entity: "Entity") -> None:
        """
        Set the entity hooked by this fish hook.

        Arguments
        - entity: the entity to set, or null to unhook
        """
        ...


    def pullHookedEntity(self) -> bool:
        """
        Pull the hooked entity to the caster of this fish hook. If no entity is
        hooked, this method has no effect.

        Returns
        - True if pulled, False if no entity is hooked
        """
        ...


    def getState(self) -> "HookState":
        """
        Get the current state of this fish hook.

        Returns
        - the fish hook state
        """
        ...


    class HookState(Enum):
        """
        Represents a state in which a fishing hook may be.
        """

        UNHOOKED = 0
        """
        The fishing hook has been cast and is either in the air or resting
        against a block on the ground.
        """
        HOOKED_ENTITY = 1
        """
        The fishing hook has hooked an entity.
        """
        BOBBING = 2
        """
        The fishing hook is bobbing in the water, waiting for a bite.
        """



from .PropertyUtils import PropertyUtils
from .MissingProperty import MissingProperty
from .GenericProperty import GenericProperty
from .PropertySubstitute import PropertySubstitute
from .Property import Property
from .FieldProperty import FieldProperty
from .BeanAccess import BeanAccess
from .MethodProperty import MethodProperty


"""
Python module generated from Java source file org.yaml.snakeyaml.events.CollectionStartEvent

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml.error import Mark
from org.yaml.snakeyaml.events import *
from typing import Any, Callable, Iterable, Tuple


class CollectionStartEvent(NodeEvent):
    """
    Base class for the start events of the collection nodes.
    """

    def __init__(self, anchor: str, tag: str, implicit: bool, startMark: "Mark", endMark: "Mark", flowStyle: "DumperOptions.FlowStyle"):
        ...


    def __init__(self, anchor: str, tag: str, implicit: bool, startMark: "Mark", endMark: "Mark", flowStyle: "Boolean"):
        ...


    def getTag(self) -> str:
        """
        Tag of this collection.

        Returns
        - The tag of this collection, or `null` if no explicit
                tag is available.
        """
        ...


    def getImplicit(self) -> bool:
        """
        `True` if the tag can be omitted while this collection is
        emitted.

        Returns
        - True if the tag can be omitted while this collection is emitted.
        """
        ...


    def getFlowStyle(self) -> "DumperOptions.FlowStyle":
        """
        `True` if this collection is in flow style, `False`
        for block style.

        Returns
        - If this collection is in flow style.
        """
        ...


    def isFlow(self) -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.entity.Enderman

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block.data import BlockData
from org.bukkit.entity import *
from org.bukkit.material import MaterialData
from typing import Any, Callable, Iterable, Tuple


class Enderman(Monster):
    """
    Represents an Enderman.
    """

    def getCarriedMaterial(self) -> "MaterialData":
        """
        Gets the id and data of the block that the Enderman is carrying.

        Returns
        - MaterialData containing the id and data of the block
        """
        ...


    def setCarriedMaterial(self, material: "MaterialData") -> None:
        """
        Sets the id and data of the block that the Enderman is carrying.

        Arguments
        - material: data to set the carried block to
        """
        ...


    def getCarriedBlock(self) -> "BlockData":
        """
        Gets the data of the block that the Enderman is carrying.

        Returns
        - BlockData containing the carried block, or null if none
        """
        ...


    def setCarriedBlock(self, blockData: "BlockData") -> None:
        """
        Sets the data of the block that the Enderman is carrying.

        Arguments
        - blockData: data to set the carried block to, or null to remove
        """
        ...



from .LongAddables import LongAddables
from .AbstractHasher import AbstractHasher
from .HashFunction import HashFunction
from .Murmur3_32HashFunction import Murmur3_32HashFunction
from .Crc32cHashFunction import Crc32cHashFunction
from .MacHashFunction import MacHashFunction
from .HashingOutputStream import HashingOutputStream
from .FarmHashFingerprint64 import FarmHashFingerprint64
from .ParametricNullness import ParametricNullness
from .AbstractHashFunction import AbstractHashFunction
from .Funnels import Funnels
from .ChecksumHashFunction import ChecksumHashFunction
from .LongAdder import LongAdder
from .HashCode import HashCode
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .ImmutableSupplier import ImmutableSupplier
from .AbstractByteHasher import AbstractByteHasher
from .SipHashFunction import SipHashFunction
from .LongAddable import LongAddable
from .HashingInputStream import HashingInputStream
from .AbstractCompositeHashFunction import AbstractCompositeHashFunction
from .AbstractStreamingHasher import AbstractStreamingHasher
from .Hasher import Hasher
from .Murmur3_128HashFunction import Murmur3_128HashFunction
from .PrimitiveSink import PrimitiveSink
from .MessageDigestHashFunction import MessageDigestHashFunction
from .Java8Compatibility import Java8Compatibility
from .Striped64 import Striped64
from .BloomFilterStrategies import BloomFilterStrategies
from .BloomFilter import BloomFilter
from .LittleEndianByteArray import LittleEndianByteArray
from .Hashing import Hashing
from .AbstractNonStreamingHashFunction import AbstractNonStreamingHashFunction
from .Funnel import Funnel


"""
Python module generated from Java source file org.bukkit.EntityEffect

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit import *
from org.bukkit.entity import Ageable
from org.bukkit.entity import ArmorStand
from org.bukkit.entity import Cat
from org.bukkit.entity import Dolphin
from org.bukkit.entity import Entity
from org.bukkit.entity import Firework
from org.bukkit.entity import Fox
from org.bukkit.entity import Guardian
from org.bukkit.entity import IronGolem
from org.bukkit.entity import LivingEntity
from org.bukkit.entity import Player
from org.bukkit.entity import Rabbit
from org.bukkit.entity import Ravager
from org.bukkit.entity import Squid
from org.bukkit.entity import Tameable
from org.bukkit.entity import TippedArrow
from org.bukkit.entity import Villager
from org.bukkit.entity import Witch
from org.bukkit.entity import Wolf
from org.bukkit.entity import ZombieVillager
from typing import Any, Callable, Iterable, Tuple


class EntityEffect(Enum):
    """
    A list of all Effects that can happen to entities.
    """

    ARROW_PARTICLES = (0, TippedArrow)
    """
    Colored particles from a tipped arrow.
    """
    RABBIT_JUMP = (1, Rabbit)
    """
    Rabbit jumping.
    """
    HURT = (2, LivingEntity)
    """
    When mobs get hurt.
    """
    DEATH = (3, Entity)
    """
    When a mob dies.
    
    **This will cause client-glitches!**

    Deprecated
    - although this effect may trigger other events on non-living
    entities, it's only supported usage is on living ones.
    """
    WOLF_SMOKE = (6, Tameable)
    """
    The smoke when taming a wolf fails.
    """
    WOLF_HEARTS = (7, Wolf)
    """
    The hearts when taming a wolf succeeds.
    """
    WOLF_SHAKE = (8, Wolf)
    """
    When a wolf shakes (after being wet).
    """
    SHEEP_EAT = (10, Entity)
    """
    When an entity eats a LONG_GRASS block.

    Deprecated
    - although this effect may trigger other events on non-living
    entities, it's only supported usage is on living ones.
    """
    IRON_GOLEM_ROSE = (11, IronGolem)
    """
    When an Iron Golem gives a rose.
    """
    VILLAGER_HEART = (12, Villager)
    """
    Hearts from a villager.
    """
    VILLAGER_ANGRY = (13, Villager)
    """
    When a villager is angry.
    """
    VILLAGER_HAPPY = (14, Villager)
    """
    Happy particles from a villager.
    """
    WITCH_MAGIC = (15, Witch)
    """
    Magic particles from a witch.
    """
    ZOMBIE_TRANSFORM = (16, ZombieVillager)
    """
    When a zombie transforms into a villager by shaking violently.
    """
    FIREWORK_EXPLODE = (17, Firework)
    """
    When a firework explodes.
    """
    LOVE_HEARTS = (18, Ageable)
    """
    Hearts from a breeding entity.
    """
    SQUID_ROTATE = (19, Squid)
    """
    Resets squid rotation.
    """
    ENTITY_POOF = (20, LivingEntity)
    """
    Silverfish entering block, spawner spawning.
    """
    GUARDIAN_TARGET = (21, Guardian)
    """
    Guardian plays the attack sound effect.
    """
    SHIELD_BLOCK = (29, LivingEntity)
    """
    Shield blocks attack.
    """
    SHIELD_BREAK = (30, LivingEntity)
    """
    Shield breaks.
    """
    ARMOR_STAND_HIT = (32, ArmorStand)
    """
    Armor stand is hit.
    """
    THORNS_HURT = (33, LivingEntity)
    """
    Entity hurt by thorns attack.
    """
    IRON_GOLEM_SHEATH = (34, IronGolem)
    """
    Iron golem puts away rose.
    """
    TOTEM_RESURRECT = (35, LivingEntity)
    """
    Totem prevents entity death.
    """
    HURT_DROWN = (36, LivingEntity)
    """
    Entity hurt due to drowning damage.
    """
    HURT_EXPLOSION = (37, LivingEntity)
    """
    Entity hurt due to explosion damage.
    """
    DOLPHIN_FED = (38, Dolphin)
    """
    Dolphin has been fed and is locating a structure.
    """
    RAVAGER_STUNNED = (39, Ravager)
    """
    Ravager has been stunned for 40 ticks.
    """
    CAT_TAME_FAIL = (40, Cat)
    """
    Cat taming failed.
    """
    CAT_TAME_SUCCESS = (41, Cat)
    """
    Cat taming succeeded.
    """
    VILLAGER_SPLASH = (42, Villager)
    """
    Villager splashes particles during a raid.
    """
    PLAYER_BAD_OMEN_RAID = (43, Player)
    """
    Player's bad omen effect removed to start or increase raid difficult.
    """
    HURT_BERRY_BUSH = (44, LivingEntity)
    """
    Entity hurt due to berry bush. Prickly!
    """
    FOX_CHEW = (45, Fox)
    """
    Fox chews the food in its mouth
    """
    TELEPORT_ENDER = (46, LivingEntity)
    """
    Entity teleported as a result of chorus fruit or as an enderman
    """
    BREAK_EQUIPMENT_MAIN_HAND = (47, LivingEntity)
    """
    Entity breaks item in main hand
    """
    BREAK_EQUIPMENT_OFF_HAND = (48, LivingEntity)
    """
    Entity breaks item in off hand
    """
    BREAK_EQUIPMENT_HELMET = (49, LivingEntity)
    """
    Entity breaks item in helmet slot
    """
    BREAK_EQUIPMENT_CHESTPLATE = (50, LivingEntity)
    """
    Entity breaks item in chestplate slot
    """
    BREAK_EQUIPMENT_LEGGINGS = (51, LivingEntity)
    """
    Entity breaks item in legging slot
    """
    BREAK_EQUIPMENT_BOOTS = (52, LivingEntity)
    """
    Entity breaks item in boot slot
    """


    def getData(self) -> int:
        """
        Gets the data value of this EntityEffect

        Returns
        - The data value

        Deprecated
        - Magic value
        """
        ...


    def getApplicable(self) -> type["Entity"]:
        """
        Gets entity superclass which this affect is applicable to.

        Returns
        - applicable class
        """
        ...



from .Stream import Stream
from .DoubleStream import DoubleStream
from .IntStream import IntStream
from .LongStream import LongStream
from .Collector import Collector
from .Collectors import Collectors
from .BaseStream import BaseStream
from .StreamSupport import StreamSupport


from .LongBinaryOperator import LongBinaryOperator
from .LongUnaryOperator import LongUnaryOperator
from .BooleanSupplier import BooleanSupplier
from .BiFunction import BiFunction
from .BiPredicate import BiPredicate
from .Function import Function
from .Predicate import Predicate
from .Consumer import Consumer
from .BinaryOperator import BinaryOperator
from .Supplier import Supplier
from .UnaryOperator import UnaryOperator
from .BiConsumer import BiConsumer
from .ToIntFunction import ToIntFunction
from .ObjIntConsumer import ObjIntConsumer
from .DoubleConsumer import DoubleConsumer
from .IntConsumer import IntConsumer
from .IntFunction import IntFunction
from .LongConsumer import LongConsumer


"""
Python module generated from Java source file com.google.gson.JsonPrimitive

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import *
from com.google.gson.internal import $Gson$Preconditions
from com.google.gson.internal import LazilyParsedNumber
from java.math import BigDecimal
from java.math import BigInteger
from typing import Any, Callable, Iterable, Tuple


class JsonPrimitive(JsonElement):
    """
    A class representing a Json primitive value. A primitive value
    is either a String, a Java primitive, or a Java primitive
    wrapper type.

    Author(s)
    - Joel Leitch
    """

    def __init__(self, bool: "Boolean"):
        """
        Create a primitive containing a boolean value.

        Arguments
        - bool: the value to create the primitive with.
        """
        ...


    def __init__(self, number: "Number"):
        """
        Create a primitive containing a Number.

        Arguments
        - number: the value to create the primitive with.
        """
        ...


    def __init__(self, string: str):
        """
        Create a primitive containing a String value.

        Arguments
        - string: the value to create the primitive with.
        """
        ...


    def __init__(self, c: "Character"):
        """
        Create a primitive containing a character. The character is turned into a one character String
        since Json only supports String.

        Arguments
        - c: the value to create the primitive with.
        """
        ...


    def deepCopy(self) -> "JsonPrimitive":
        """
        Returns the same value as primitives are immutable.

        Since
        - 2.8.2
        """
        ...


    def isBoolean(self) -> bool:
        """
        Check whether this primitive contains a boolean value.

        Returns
        - True if this primitive contains a boolean value, False otherwise.
        """
        ...


    def getAsBoolean(self) -> bool:
        """
        convenience method to get this element as a boolean value.

        Returns
        - get this element as a primitive boolean value.
        """
        ...


    def isNumber(self) -> bool:
        """
        Check whether this primitive contains a Number.

        Returns
        - True if this primitive contains a Number, False otherwise.
        """
        ...


    def getAsNumber(self) -> "Number":
        """
        convenience method to get this element as a Number.

        Returns
        - get this element as a Number.

        Raises
        - NumberFormatException: if the value contained is not a valid Number.
        """
        ...


    def isString(self) -> bool:
        """
        Check whether this primitive contains a String value.

        Returns
        - True if this primitive contains a String value, False otherwise.
        """
        ...


    def getAsString(self) -> str:
        """
        convenience method to get this element as a String.

        Returns
        - get this element as a String.
        """
        ...


    def getAsDouble(self) -> float:
        """
        convenience method to get this element as a primitive double.

        Returns
        - get this element as a primitive double.

        Raises
        - NumberFormatException: if the value contained is not a valid double.
        """
        ...


    def getAsBigDecimal(self) -> "BigDecimal":
        """
        convenience method to get this element as a BigDecimal.

        Returns
        - get this element as a BigDecimal.

        Raises
        - NumberFormatException: if the value contained is not a valid BigDecimal.
        """
        ...


    def getAsBigInteger(self) -> "BigInteger":
        """
        convenience method to get this element as a BigInteger.

        Returns
        - get this element as a BigInteger.

        Raises
        - NumberFormatException: if the value contained is not a valid BigInteger.
        """
        ...


    def getAsFloat(self) -> float:
        """
        convenience method to get this element as a float.

        Returns
        - get this element as a float.

        Raises
        - NumberFormatException: if the value contained is not a valid float.
        """
        ...


    def getAsLong(self) -> int:
        """
        convenience method to get this element as a primitive long.

        Returns
        - get this element as a primitive long.

        Raises
        - NumberFormatException: if the value contained is not a valid long.
        """
        ...


    def getAsShort(self) -> int:
        """
        convenience method to get this element as a primitive short.

        Returns
        - get this element as a primitive short.

        Raises
        - NumberFormatException: if the value contained is not a valid short value.
        """
        ...


    def getAsInt(self) -> int:
        """
        convenience method to get this element as a primitive integer.

        Returns
        - get this element as a primitive integer.

        Raises
        - NumberFormatException: if the value contained is not a valid integer.
        """
        ...


    def getAsByte(self) -> int:
        ...


    def getAsCharacter(self) -> str:
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.UnicodeEscaper

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class UnicodeEscaper(Escaper):
    """
    An Escaper that converts literal text into a format safe for
    inclusion in a particular context (such as an XML document). Typically (but
    not always), the inverse process of "unescaping" the text is performed
    automatically by the relevant parser.
    
    
    For example, an XML escaper would convert the literal string
    `"Foo<Bar>"` into `"Foo&lt;Bar&gt;"` to prevent `"<Bar>"`
    from being confused with an XML tag. When the resulting XML document is
    parsed, the parser API will return this text as the original literal string
    `"Foo<Bar>"`.
    
    
    **Note:** This class is similar to CharEscaper but with one very
    important difference. A CharEscaper can only process Java <a
    href="http://en.wikipedia.org/wiki/UTF-16">UTF16</a> characters in isolation
    and may not cope when it encounters surrogate pairs. This class facilitates
    the correct escaping of all Unicode characters.
    
    
    As there are important reasons, including potential security issues, to
    handle Unicode correctly if you are considering implementing a new escaper
    you should favor using UnicodeEscaper wherever possible.
    
    
    A `UnicodeEscaper` instance is required to be stateless, and safe when
    used concurrently by multiple threads.
    
    
    Several popular escapers are defined as constants in the class
    CharEscapers. To create your own escapers extend this class and
    implement the .escape(int) method.
    """

    def escape(self, string: str) -> str:
        """
        Returns the escaped form of a given literal string.
        
        
        If you are escaping input in arbitrary successive chunks, then it is not
        generally safe to use this method. If an input string ends with an
        unmatched high surrogate character, then this method will throw
        IllegalArgumentException. You should either ensure your input is
        valid <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a> before
        calling this method or use an escaped Appendable (as returned by
        .escape(Appendable)) which can cope with arbitrarily split input.
        
        
        **Note:** When implementing an escaper it is a good idea to override
        this method for efficiency by inlining the implementation of
        .nextEscapeIndex(CharSequence, int, int) directly. Doing this for
        PercentEscaper more than doubled the performance for unescaped
        strings (as measured by CharEscapersBenchmark).

        Arguments
        - string: the literal string to be escaped

        Returns
        - the escaped form of `string`

        Raises
        - NullPointerException: if `string` is null
        - IllegalArgumentException: if invalid surrogate characters are encountered
        """
        ...


    def escape(self, out: "Appendable") -> "Appendable":
        """
        Returns an `Appendable` instance which automatically escapes all
        text appended to it before passing the resulting text to an underlying
        `Appendable`.
        
        
        Unlike .escape(String) it is permitted to append arbitrarily
        split input to this Appendable, including input that is split over a
        surrogate pair. In this case the pending high surrogate character will
        not be processed until the corresponding low surrogate is appended. This
        means that a trailing high surrogate character at the end of the input
        cannot be detected and will be silently ignored. This is unavoidable
        since the Appendable interface has no `close()` method, and it is
        impossible to determine when the last characters have been appended.
        
        
        The methods of the returned object will propagate any exceptions thrown
        by the underlying `Appendable`.
        
        
        For well formed <a href="http://en.wikipedia.org/wiki/UTF-16">UTF-16</a>
        the escaping behavior is identical to that of .escape(String) and
        the following code is equivalent to (but much slower than)
        `escaper.escape(string)`:
        
        ```
        {
            &#064;code
            StringBuilder sb = new StringBuilder();
            escaper.escape(sb).append(string);
            return sb.toString();
        }
        ```

        Arguments
        - out: the underlying `Appendable` to append escaped output to

        Returns
        - an `Appendable` which passes text to `out` after
                escaping it

        Raises
        - NullPointerException: if `out` is null
        - IllegalArgumentException: if invalid surrogate characters are encountered
        """
        ...



"""
Python module generated from Java source file com.google.gson.internal.reflect.UnsafeReflectionAccessor

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson import JsonIOException
from com.google.gson.internal.reflect import *
from java.lang.reflect import AccessibleObject
from java.lang.reflect import Field
from java.lang.reflect import Method
from typing import Any, Callable, Iterable, Tuple


class UnsafeReflectionAccessor(ReflectionAccessor):
    """
    An implementation of ReflectionAccessor based on Unsafe.
    
    NOTE: This implementation is designed for Java 9. Although it should work with earlier Java releases, it is better to
    use PreJava9ReflectionAccessor for them.
    """

    def makeAccessible(self, ao: "AccessibleObject") -> None:
        """

        """
        ...



"""
Python module generated from Java source file org.bukkit.entity.LightningStrike

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class LightningStrike(Entity):
    """
    Represents an instance of a lightning strike. May or may not do damage.
    """

    def isEffect(self) -> bool:
        """
        Returns whether the strike is an effect that does no damage.

        Returns
        - whether the strike is an effect
        """
        ...


    def spigot(self) -> "Spigot":
        ...


    class Spigot(Spigot):

        def isSilent(self) -> bool:
            ...



from .Bytes import Bytes
from .Doubles import Doubles
from .Ints import Ints
from .ImmutableIntArray import ImmutableIntArray
from .ImmutableLongArray import ImmutableLongArray
from .UnsignedInts import UnsignedInts
from .ParametricNullness import ParametricNullness
from .ParseRequest import ParseRequest
from .ShortsMethodsForWeb import ShortsMethodsForWeb
from .UnsignedBytes import UnsignedBytes
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .IntsMethodsForWeb import IntsMethodsForWeb
from .FloatsMethodsForWeb import FloatsMethodsForWeb
from .Longs import Longs
from .Chars import Chars
from .UnsignedLongs import UnsignedLongs
from .Shorts import Shorts
from .UnsignedInteger import UnsignedInteger
from .Booleans import Booleans
from .UnsignedLong import UnsignedLong
from .Platform import Platform
from .DoublesMethodsForWeb import DoublesMethodsForWeb
from .Primitives import Primitives
from .ImmutableDoubleArray import ImmutableDoubleArray
from .SignedBytes import SignedBytes
from .Floats import Floats


"""
Python module generated from Java source file com.google.gson.internal.reflect.ReflectionAccessor

Java source file obtained from artifact gson version 2.8.9

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.gson.internal import JavaVersion
from com.google.gson.internal.reflect import *
from java.lang.reflect import AccessibleObject
from typing import Any, Callable, Iterable, Tuple


class ReflectionAccessor:
    """
    Provides a replacement for AccessibleObject.setAccessible(boolean), which may be used to
    avoid reflective access issues appeared in Java 9, like java.lang.reflect.InaccessibleObjectException
    thrown or warnings like
    ```
      WARNING: An illegal reflective access operation has occurred
      WARNING: Illegal reflective access by ...
    ```
    <p/>
    Works both for Java 9 and earlier Java versions.
    """

    def makeAccessible(self, ao: "AccessibleObject") -> None:
        """
        Does the same as `ao.setAccessible(True)`, but never throws
        java.lang.reflect.InaccessibleObjectException
        """
        ...


    @staticmethod
    def getInstance() -> "ReflectionAccessor":
        """
        Obtains a ReflectionAccessor instance suitable for the current Java version.
        
        You may need one a reflective operation in your code throws java.lang.reflect.InaccessibleObjectException.
        In such a case, use ReflectionAccessor.makeAccessible(AccessibleObject) on a field, method or constructor
        (instead of basic AccessibleObject.setAccessible(boolean)).
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.resolver.Resolver

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.regex import Pattern
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.resolver import *
from typing import Any, Callable, Iterable, Tuple


class Resolver:
    """
    Resolver tries to detect a type by content (when the tag is implicit)
    """

    BOOL = Pattern.compile("^(?:yes|Yes|YES|no|No|NO|true|True|TRUE|false|False|FALSE|on|On|ON|off|Off|OFF)$")
    FLOAT = Pattern.compile("^(" + // (base 10)
    "[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+]?[0-9]+)?" + // (base 10, scientific notation without .)
    "|[-+]?(?:[0-9][0-9_]*)(?:[eE][-+]?[0-9]+)" + // (base 10, starting with .)
    "|[-+]?\\.[0-9_]+(?:[eE][-+]?[0-9]+)?" + // (base 60)
    "|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*" + "|[-+]?\\.(?:inf|Inf|INF)" + "|\\.(?:nan|NaN|NAN)" + ")$")
    """
    The regular expression is taken from the 1.2 specification but '_'s are
    added to keep backwards compatibility
    """
    INT = Pattern.compile("^(?:" + // (base 2)
    "[-+]?0b_*[0-1]+[0-1_]*" + // (base 8)
    "|[-+]?0_*[0-7]+[0-7_]*" + // (base 10)
    "|[-+]?(?:0|[1-9][0-9_]*)" + // (base 16)
    "|[-+]?0x_*[0-9a-fA-F]+[0-9a-fA-F_]*" + // (base 60)
    "|[-+]?[1-9][0-9_]*(?::[0-5]?[0-9])+" + ")$")
    MERGE = Pattern.compile("^(?:<<)$")
    NULL = Pattern.compile("^(?:~|null|Null|NULL| )$")
    EMPTY = Pattern.compile("^$")
    TIMESTAMP = Pattern.compile("^(?:[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]|[0-9][0-9][0-9][0-9]-[0-9][0-9]?-[0-9][0-9]?(?:[Tt]|[ \t]+)[0-9][0-9]?:[0-9][0-9]:[0-9][0-9](?:\\.[0-9]*)?(?:[ \t]*(?:Z|[-+][0-9][0-9]?(?::[0-9][0-9])?))?)$")
    VALUE = Pattern.compile("^(?:=)$")
    YAML = Pattern.compile("^(?:!|&|\\*)$")


    def __init__(self):
        ...


    def addImplicitResolver(self, tag: "Tag", regexp: "Pattern", first: str) -> None:
        ...


    def resolve(self, kind: "NodeId", value: str, implicit: bool) -> "Tag":
        ...



"""
Python module generated from Java source file org.bukkit.GameEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import Collections
from org.bukkit import *
from typing import Any, Callable, Iterable, Tuple


class GameEvent(Keyed):
    """
    Represents a generic Mojang game event.
    """

    BLOCK_ATTACH = getEvent("block_attach")
    BLOCK_CHANGE = getEvent("block_change")
    BLOCK_CLOSE = getEvent("block_close")
    BLOCK_DESTROY = getEvent("block_destroy")
    BLOCK_DETACH = getEvent("block_detach")
    BLOCK_OPEN = getEvent("block_open")
    BLOCK_PLACE = getEvent("block_place")
    BLOCK_PRESS = getEvent("block_press")
    BLOCK_SWITCH = getEvent("block_switch")
    BLOCK_UNPRESS = getEvent("block_unpress")
    BLOCK_UNSWITCH = getEvent("block_unswitch")
    CONTAINER_CLOSE = getEvent("container_close")
    CONTAINER_OPEN = getEvent("container_open")
    DISPENSE_FAIL = getEvent("dispense_fail")
    DRINKING_FINISH = getEvent("drinking_finish")
    EAT = getEvent("eat")
    ELYTRA_FREE_FALL = getEvent("elytra_free_fall")
    ENTITY_DAMAGED = getEvent("entity_damaged")
    ENTITY_KILLED = getEvent("entity_killed")
    ENTITY_PLACE = getEvent("entity_place")
    EQUIP = getEvent("equip")
    EXPLODE = getEvent("explode")
    FISHING_ROD_CAST = getEvent("fishing_rod_cast")
    FISHING_ROD_REEL_IN = getEvent("fishing_rod_reel_in")
    FLAP = getEvent("flap")
    FLUID_PICKUP = getEvent("fluid_pickup")
    FLUID_PLACE = getEvent("fluid_place")
    HIT_GROUND = getEvent("hit_ground")
    LIGHTNING_STRIKE = getEvent("lightning_strike")
    MINECART_MOVING = getEvent("minecart_moving")
    MOB_INTERACT = getEvent("mob_interact")
    PISTON_CONTRACT = getEvent("piston_contract")
    PISTON_EXTEND = getEvent("piston_extend")
    PRIME_FUSE = getEvent("prime_fuse")
    PROJECTILE_LAND = getEvent("projectile_land")
    PROJECTILE_SHOOT = getEvent("projectile_shoot")
    RAVAGER_ROAR = getEvent("ravager_roar")
    RING_BELL = getEvent("ring_bell")
    SHEAR = getEvent("shear")
    SHULKER_CLOSE = getEvent("shulker_close")
    SHULKER_OPEN = getEvent("shulker_open")
    SPLASH = getEvent("splash")
    STEP = getEvent("step")
    SWIM = getEvent("swim")
    WOLF_SHAKING = getEvent("wolf_shaking")


    def getKey(self) -> "NamespacedKey":
        ...


    @staticmethod
    def getByKey(namespacedKey: "NamespacedKey") -> "GameEvent":
        """
        Returns a GameEvent by a NamespacedKey.

        Arguments
        - namespacedKey: the key

        Returns
        - the event or null
        """
        ...


    @staticmethod
    def values() -> Iterable["GameEvent"]:
        """
        Returns the set of all GameEvents.

        Returns
        - the memoryKeys
        """
        ...



"""
Python module generated from Java source file com.google.common.io.ParametricNullness

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.io import *
from javax.annotation import Nonnull
from javax.annotation.meta import TypeQualifierNickname
from typing import Any, Callable, Iterable, Tuple


class ParametricNullness:
    """
    Marks a "top-level" type-variable usage as (a) a Kotlin platform type when the type argument is
    non-nullable and (b) nullable when the type argument is nullable. This is the closest we can get
    to "non-nullable when non-nullable; nullable when nullable" (like the Android <a
    href="https://android.googlesource.com/platform/libcore/+/master/luni/src/main/java/libcore/util/NullFromTypeParam.java">`NullFromTypeParam`</a>). We use this to "undo" ElementTypesAreNonnullByDefault.
    """





"""
Python module generated from Java source file com.google.common.collect.ClassToInstanceMap

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotMock
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ClassToInstanceMap(Map):
    """
    A map, each entry of which maps a Java <a href="http://tinyurl.com/2cmwkz">raw type</a> to an
    instance of that type. In addition to implementing `Map`, the additional type-safe
    operations .putInstance and .getInstance are available.
    
    Like any other `Map<Class, Object>`, this map may contain entries for primitive types,
    and a primitive type and its corresponding wrapper type may map to different values.
    
    This class's support for `null` requires some explanation: From release 31.0 onward,
    Guava specifies the nullness of its types through annotations. In the case of `ClassToInstanceMap`, it specifies that both the key and value types are restricted to
    non-nullable types. This specification is reasonable for *keys*, which must be non-null
    classes. This is in contrast to the specification for *values*: Null values *are*
    supported by the implementation MutableClassToInstanceMap, even though that
    implementation and this interface specify otherwise. Thus, if you use a nullness checker, you can
    safely suppress any warnings it produces when you write null values into a `MutableClassToInstanceMap`. Just be sure to be prepared for null values when reading from it,
    since nullness checkers will assume that vaules are non-null then, too.
    
    See the Guava User Guide article on <a href=
    "https://github.com/google/guava/wiki/NewCollectionTypesExplained#classtoinstancemap">`ClassToInstanceMap`</a>.
    
    To map a generic type to an instance of that type, use com.google.common.reflect.TypeToInstanceMap instead.
    
    Type `<B>`: the common supertype that all entries must share; often this is simply Object

    Author(s)
    - Kevin Bourrillion

    Since
    - 2.0
    """

    def getInstance(self, type: type["T"]) -> "T":
        """
        Returns the value the specified class is mapped to, or `null` if no entry for this class
        is present. This will only return a value that was bound to this specific class, not a value
        that may have been bound to a subtype.
        """
        ...


    def putInstance(self, type: type["T"], value: "T") -> "T":
        """
        Maps the specified class to the specified value. Does *not* associate this value with any
        of the class's supertypes.

        Returns
        - the value previously associated with this class (possibly `null`), or `null` if there was no previous entry.
        """
        ...



from .SortedIterable import SortedIterable
from .TreeRangeMap import TreeRangeMap
from .ForwardingSetMultimap import ForwardingSetMultimap
from .TableCollectors import TableCollectors
from .Table import Table
from .ForwardingObject import ForwardingObject
from .ImmutableList import ImmutableList
from .ForwardingList import ForwardingList
from .ImmutableMap import ImmutableMap
from .LinkedHashMultimapGwtSerializationDependencies import LinkedHashMultimapGwtSerializationDependencies
from .FilteredEntryMultimap import FilteredEntryMultimap
from .ImmutableSortedSet import ImmutableSortedSet
from .PeekingIterator import PeekingIterator
from .AbstractMultimap import AbstractMultimap
from .ImmutableEnumMap import ImmutableEnumMap
from .ForwardingDeque import ForwardingDeque
from .SortedMultiset import SortedMultiset
from .NaturalOrdering import NaturalOrdering
from .ImmutableTable import ImmutableTable
from .SortedMapDifference import SortedMapDifference
from .Serialization import Serialization
from .Queues import Queues
from .ImmutableRangeMap import ImmutableRangeMap
from .ImmutableSortedMultiset import ImmutableSortedMultiset
from .RangeGwtSerializationDependencies import RangeGwtSerializationDependencies
from .LinkedHashMultiset import LinkedHashMultiset
from .SortedIterables import SortedIterables
from .ForwardingIterator import ForwardingIterator
from .ReverseNaturalOrdering import ReverseNaturalOrdering
from .SingletonImmutableList import SingletonImmutableList
from .ImmutableBiMap import ImmutableBiMap
from .ImmutableBiMapFauxverideShim import ImmutableBiMapFauxverideShim
from .GeneralRange import GeneralRange
from .ImmutableSet import ImmutableSet
from .AbstractMapEntry import AbstractMapEntry
from .RegularImmutableTable import RegularImmutableTable
from .EnumMultiset import EnumMultiset
from .MutableClassToInstanceMap import MutableClassToInstanceMap
from .AbstractSortedSetMultimap import AbstractSortedSetMultimap
from .Multisets import Multisets
from .CollectPreconditions import CollectPreconditions
from .AbstractIndexedListIterator import AbstractIndexedListIterator
from .ArrayListMultimapGwtSerializationDependencies import ArrayListMultimapGwtSerializationDependencies
from .TransformedIterator import TransformedIterator
from .NullnessCasts import NullnessCasts
from .HashBiMap import HashBiMap
from .ForwardingSortedMap import ForwardingSortedMap
from .ByFunctionOrdering import ByFunctionOrdering
from .ForwardingListMultimap import ForwardingListMultimap
from .CompactHashSet import CompactHashSet
from .UnmodifiableListIterator import UnmodifiableListIterator
from .Collections2 import Collections2
from .Multimap import Multimap
from .NullsFirstOrdering import NullsFirstOrdering
from .RegularContiguousSet import RegularContiguousSet
from .EmptyContiguousSet import EmptyContiguousSet
from .ParametricNullness import ParametricNullness
from .ImmutableMultiset import ImmutableMultiset
from .ImmutableEntry import ImmutableEntry
from .TreeBasedTable import TreeBasedTable
from .UnmodifiableSortedMultiset import UnmodifiableSortedMultiset
from .SortedLists import SortedLists
from .AbstractSetMultimap import AbstractSetMultimap
from .TransformedListIterator import TransformedListIterator
from .TreeMultiset import TreeMultiset
from .ArrayTable import ArrayTable
from .ContiguousSet import ContiguousSet
from .AbstractRangeSet import AbstractRangeSet
from .TreeMultimap import TreeMultimap
from .UsingToStringOrdering import UsingToStringOrdering
from .AbstractMapBasedMultiset import AbstractMapBasedMultiset
from .RegularImmutableList import RegularImmutableList
from .ForwardingImmutableList import ForwardingImmutableList
from .ImmutableMultisetGwtSerializationDependencies import ImmutableMultisetGwtSerializationDependencies
from .AbstractNavigableMap import AbstractNavigableMap
from .FilteredKeyMultimap import FilteredKeyMultimap
from .ImmutableCollection import ImmutableCollection
from .Ordering import Ordering
from .Cut import Cut
from .ForwardingCollection import ForwardingCollection
from .ReverseOrdering import ReverseOrdering
from .SetMultimap import SetMultimap
from .ImmutableSortedMapFauxverideShim import ImmutableSortedMapFauxverideShim
from .CollectSpliterators import CollectSpliterators
from .ImmutableSortedMap import ImmutableSortedMap
from .NullsLastOrdering import NullsLastOrdering
from .DescendingImmutableSortedMultiset import DescendingImmutableSortedMultiset
from .Tables import Tables
from .ForwardingConcurrentMap import ForwardingConcurrentMap
from .Maps import Maps
from .RangeSet import RangeSet
from .ImmutableMapEntrySet import ImmutableMapEntrySet
from .ForwardingSortedSet import ForwardingSortedSet
from .JdkBackedImmutableSet import JdkBackedImmutableSet
from .Streams import Streams
from .AbstractSortedMultiset import AbstractSortedMultiset
from .AllEqualOrdering import AllEqualOrdering
from .HashMultiset import HashMultiset
from .JdkBackedImmutableMap import JdkBackedImmutableMap
from .ImmutableSortedSetFauxverideShim import ImmutableSortedSetFauxverideShim
from .CompoundOrdering import CompoundOrdering
from .ComputationException import ComputationException
from .FluentIterable import FluentIterable
from .ElementTypesAreNonnullByDefault import ElementTypesAreNonnullByDefault
from .JdkBackedImmutableBiMap import JdkBackedImmutableBiMap
from .RangeMap import RangeMap
from .SortedMultisetBridge import SortedMultisetBridge
from .Range import Range
from .Multimaps import Multimaps
from .RegularImmutableMap import RegularImmutableMap
from .MoreCollectors import MoreCollectors
from .ForwardingImmutableMap import ForwardingImmutableMap
from .Synchronized import Synchronized
from .ImmutableSetMultimap import ImmutableSetMultimap
from .AbstractListMultimap import AbstractListMultimap
from .ExplicitOrdering import ExplicitOrdering
from .SortedSetMultimap import SortedSetMultimap
from .ForwardingListIterator import ForwardingListIterator
from .Iterators import Iterators
from .RegularImmutableSortedMultiset import RegularImmutableSortedMultiset
from .HashMultimapGwtSerializationDependencies import HashMultimapGwtSerializationDependencies
from .ClassToInstanceMap import ClassToInstanceMap
from .DenseImmutableTable import DenseImmutableTable
from .EmptyImmutableSetMultimap import EmptyImmutableSetMultimap
from .TopKSelector import TopKSelector
from .FilteredEntrySetMultimap import FilteredEntrySetMultimap
from .Sets import Sets
from .ForwardingSortedMultiset import ForwardingSortedMultiset
from .DiscreteDomain import DiscreteDomain
from .Multiset import Multiset
from .LexicographicalOrdering import LexicographicalOrdering
from .ObjectArrays import ObjectArrays
from .ForwardingSet import ForwardingSet
from .ForwardingImmutableCollection import ForwardingImmutableCollection
from .FilteredKeySetMultimap import FilteredKeySetMultimap
from .ForwardingMap import ForwardingMap
from .StandardRowSortedTable import StandardRowSortedTable
from .CompactHashMap import CompactHashMap
from .ForwardingMultimap import ForwardingMultimap
from .ForwardingMultiset import ForwardingMultiset
from .AbstractSequentialIterator import AbstractSequentialIterator
from .ForwardingBlockingDeque import ForwardingBlockingDeque
from .ForwardingImmutableSet import ForwardingImmutableSet
from .Lists import Lists
from .CompactLinkedHashMap import CompactLinkedHashMap
from .SingletonImmutableTable import SingletonImmutableTable
from .ImmutableSortedMultisetFauxverideShim import ImmutableSortedMultisetFauxverideShim
from .ImmutableClassToInstanceMap import ImmutableClassToInstanceMap
from .MapMaker import MapMaker
from .AbstractMapBasedMultimap import AbstractMapBasedMultimap
from .ImmutableEnumSet import ImmutableEnumSet
from .FilteredMultimapValues import FilteredMultimapValues
from .AbstractIterator import AbstractIterator
from .LinkedListMultimap import LinkedListMultimap
from .ImmutableSortedAsList import ImmutableSortedAsList
from .ForwardingNavigableSet import ForwardingNavigableSet
from .IndexedImmutableSet import IndexedImmutableSet
from .MapDifference import MapDifference
from .Comparators import Comparators
from .ImmutableMapValues import ImmutableMapValues
from .Iterables import Iterables
from .BoundType import BoundType
from .Interner import Interner
from .Platform import Platform
from .ForwardingQueue import ForwardingQueue
from .CompactLinkedHashSet import CompactLinkedHashSet
from .TreeTraverser import TreeTraverser
from .RegularImmutableMultiset import RegularImmutableMultiset
from .EnumHashBiMap import EnumHashBiMap
from .Count import Count
from .EnumBiMap import EnumBiMap
from .MapMakerInternalMap import MapMakerInternalMap
from .SingletonImmutableBiMap import SingletonImmutableBiMap
from .ImmutableAsList import ImmutableAsList
from .HashBasedTable import HashBasedTable
from .HashMultimap import HashMultimap
from .FilteredMultimap import FilteredMultimap
from .SparseImmutableTable import SparseImmutableTable
from .ImmutableListMultimap import ImmutableListMultimap
from .FilteredKeyListMultimap import FilteredKeyListMultimap
from .ForwardingSortedSetMultimap import ForwardingSortedSetMultimap
from .SortedMultisets import SortedMultisets
from .BaseImmutableMultimap import BaseImmutableMultimap
from .ForwardingTable import ForwardingTable
from .ComparisonChain import ComparisonChain
from .ListMultimap import ListMultimap
from .CollectCollectors import CollectCollectors
from .AbstractBiMap import AbstractBiMap
from .UnmodifiableIterator import UnmodifiableIterator
from .AbstractSortedKeySortedSetMultimap import AbstractSortedKeySortedSetMultimap
from .RowSortedTable import RowSortedTable
from .BiMap import BiMap
from .ImmutableMultimap import ImmutableMultimap
from .JdkBackedImmutableMultiset import JdkBackedImmutableMultiset
from .AbstractTable import AbstractTable
from .RegularImmutableBiMap import RegularImmutableBiMap
from .MinMaxPriorityQueue import MinMaxPriorityQueue
from .RegularImmutableAsList import RegularImmutableAsList
from .ForwardingMapEntry import ForwardingMapEntry
from .CartesianList import CartesianList
from .AbstractMultiset import AbstractMultiset
from .LinkedHashMultimap import LinkedHashMultimap
from .EvictingQueue import EvictingQueue
from .ConcurrentHashMultiset import ConcurrentHashMultiset
from .ImmutableRangeSet import ImmutableRangeSet
from .FilteredSetMultimap import FilteredSetMultimap
from .ImmutableMapKeySet import ImmutableMapKeySet
from .ComparatorOrdering import ComparatorOrdering
from .RegularImmutableSet import RegularImmutableSet
from .MultimapBuilder import MultimapBuilder
from .TreeRangeSet import TreeRangeSet
from .CompactHashing import CompactHashing
from .Interners import Interners
from .DescendingMultiset import DescendingMultiset
from .GwtTransient import GwtTransient
from .DescendingImmutableSortedSet import DescendingImmutableSortedSet
from .Hashing import Hashing
from .ConsumingQueueIterator import ConsumingQueueIterator
from .ForwardingNavigableMap import ForwardingNavigableMap
from .SingletonImmutableSet import SingletonImmutableSet
from .ImmutableMapEntry import ImmutableMapEntry
from .ArrayListMultimap import ArrayListMultimap
from .EmptyImmutableListMultimap import EmptyImmutableListMultimap
from .StandardTable import StandardTable
from .RegularImmutableSortedSet import RegularImmutableSortedSet


"""
Python module generated from Java source file org.bukkit.command.TabExecutor

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.command import *
from typing import Any, Callable, Iterable, Tuple


class TabExecutor(TabCompleter, CommandExecutor):
    """
    This class is provided as a convenience to implement both TabCompleter and
    CommandExecutor.
    """





"""
Python module generated from Java source file org.spigotmc.event.entity.EntityDismountEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import EntityEvent
from org.spigotmc.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityDismountEvent(EntityEvent, Cancellable):
    """
    Called when an entity stops riding another entity.
    """

    def __init__(self, what: "Entity", dismounted: "Entity"):
        ...


    def getDismounted(self) -> "Entity":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.PotionSplashEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.apache.commons.lang import Validate
from org.bukkit.entity import LivingEntity
from org.bukkit.entity import ThrownPotion
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class PotionSplashEvent(ProjectileHitEvent, Cancellable):
    """
    Called when a splash potion hits an area
    """

    def __init__(self, potion: "ThrownPotion", affectedEntities: dict["LivingEntity", "Double"]):
        ...


    def getEntity(self) -> "ThrownPotion":
        ...


    def getPotion(self) -> "ThrownPotion":
        """
        Gets the potion which caused this event

        Returns
        - The thrown potion entity
        """
        ...


    def getAffectedEntities(self) -> Iterable["LivingEntity"]:
        """
        Retrieves a list of all effected entities

        Returns
        - A fresh copy of the affected entity list
        """
        ...


    def getIntensity(self, entity: "LivingEntity") -> float:
        """
        Gets the intensity of the potion's effects for given entity; This
        depends on the distance to the impact center

        Arguments
        - entity: Which entity to get intensity for

        Returns
        - intensity relative to maximum effect; 0.0: not affected; 1.0:
            fully hit by potion effects
        """
        ...


    def setIntensity(self, entity: "LivingEntity", intensity: float) -> None:
        """
        Overwrites the intensity for a given entity

        Arguments
        - entity: For which entity to define a new intensity
        - intensity: relative to maximum effect
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.Jukebox

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class Jukebox(TileState):
    """
    Represents a captured state of a jukebox.
    """

    def getPlaying(self) -> "Material":
        """
        Gets the record inserted into the jukebox.

        Returns
        - The record Material, or AIR if none is inserted
        """
        ...


    def setPlaying(self, record: "Material") -> None:
        """
        Sets the record being played.

        Arguments
        - record: The record Material, or null/AIR to stop playing
        """
        ...


    def getRecord(self) -> "ItemStack":
        """
        Gets the record item inserted into the jukebox.

        Returns
        - a copy of the inserted record, or an air stack if none
        """
        ...


    def setRecord(self, record: "ItemStack") -> None:
        """
        Sets the record being played.

        Arguments
        - record: the record to insert or null/AIR to empty
        """
        ...


    def isPlaying(self) -> bool:
        """
        Checks if the jukebox is playing a record.

        Returns
        - True if there is a record playing
        """
        ...


    def stopPlaying(self) -> None:
        """
        Stops the jukebox playing without ejecting the record.
        """
        ...


    def eject(self) -> bool:
        """
        Stops the jukebox playing and ejects the current record.
        
        If the block represented by this state is no longer a jukebox, this will
        do nothing and return False.

        Returns
        - True if a record was ejected; False if there was none playing

        Raises
        - IllegalStateException: if this block state is not placed
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.LoaderOptions

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml import *
from typing import Any, Callable, Iterable, Tuple


class LoaderOptions:

    def isAllowDuplicateKeys(self) -> bool:
        ...


    def setAllowDuplicateKeys(self, allowDuplicateKeys: bool) -> None:
        """
        Allow/Reject duplicate map keys in the YAML file.
        
        Default is to allow.
        
        YAML 1.1 is slightly vague around duplicate entries in the YAML file. The
        best reference is <a href="http://www.yaml.org/spec/1.1/#id862121">
        3.2.1.3. Nodes Comparison</a> where it hints that a duplicate map key is
        an error.
        
        For future reference, YAML spec 1.2 is clear. The keys MUST be unique.
        <a href="http://www.yaml.org/spec/1.2/spec.html#id2759572">1.3. Relation
        to JSON</a>

        Arguments
        - allowDuplicateKeys: False to reject duplicate mapping keys
        """
        ...


    def isWrappedToRootException(self) -> bool:
        ...


    def setWrappedToRootException(self, wrappedToRootException: bool) -> None:
        """
        Wrap runtime exception to YAMLException during parsing or leave them as they are
        
        Default is to leave original exceptions

        Arguments
        - wrappedToRootException: - True to convert runtime exception to YAMLException
        """
        ...


    def getMaxAliasesForCollections(self) -> int:
        ...


    def setMaxAliasesForCollections(self, maxAliasesForCollections: int) -> None:
        """
        Restrict the amount of aliases for collections (sequences and mappings) to avoid https://en.wikipedia.org/wiki/Billion_laughs_attack

        Arguments
        - maxAliasesForCollections: set max allowed value (50 by default)
        """
        ...


    def setAllowRecursiveKeys(self, allowRecursiveKeys: bool) -> None:
        """
        Allow recursive keys for mappings. By default it is not allowed.
        This setting only prevents the case when the key is the value. If the key is only a part of the value
        (the value is a sequence or a mapping) then this case is not recognized and always allowed.

        Arguments
        - allowRecursiveKeys: - False to disable recursive keys
        """
        ...


    def getAllowRecursiveKeys(self) -> bool:
        ...


    def setProcessComments(self, processComments: bool) -> None:
        """
        Set the comment processing. By default comments are ignored.

        Arguments
        - processComments: `True` to process; `False` to ignore`
        """
        ...


    def isProcessComments(self) -> bool:
        ...


    def isEnumCaseSensitive(self) -> bool:
        ...


    def setEnumCaseSensitive(self, enumCaseSensitive: bool) -> None:
        """
        Disables or enables case sensitivity during construct enum constant from string value
        Default is False.

        Arguments
        - enumCaseSensitive: - True to set enum case sensitive, False the reverse
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.player.PlayerChangedWorldEvent

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import World
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerChangedWorldEvent(PlayerEvent):
    """
    Called when a player switches to another world.
    """

    def __init__(self, player: "Player", from: "World"):
        ...


    def getFrom(self) -> "World":
        """
        Gets the world the player is switching from.

        Returns
        - player's previous world
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.enchantments.EnchantmentWrapper

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import NamespacedKey
from org.bukkit.enchantments import *
from org.bukkit.inventory import ItemStack
from typing import Any, Callable, Iterable, Tuple


class EnchantmentWrapper(Enchantment):
    """
    A simple wrapper for ease of selecting Enchantments
    """

    def __init__(self, name: str):
        ...


    def getEnchantment(self) -> "Enchantment":
        """
        Gets the enchantment bound to this wrapper

        Returns
        - Enchantment
        """
        ...


    def getMaxLevel(self) -> int:
        ...


    def getStartLevel(self) -> int:
        ...


    def getItemTarget(self) -> "EnchantmentTarget":
        ...


    def canEnchantItem(self, item: "ItemStack") -> bool:
        ...


    def getName(self) -> str:
        ...


    def isTreasure(self) -> bool:
        ...


    def isCursed(self) -> bool:
        ...


    def conflictsWith(self, other: "Enchantment") -> bool:
        ...



"""
Python module generated from Java source file org.bukkit.configuration.file.BukkitYaml

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import IOException
from java.io import Writer
from java.lang.reflect import Field
from java.util import ArrayDeque
from java.util import Queue
from org.bukkit.configuration.file import *
from org.yaml.snakeyaml import DumperOptions
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml import Yaml
from org.yaml.snakeyaml.comments import CommentEventsCollector
from org.yaml.snakeyaml.comments import CommentType
from org.yaml.snakeyaml.constructor import BaseConstructor
from org.yaml.snakeyaml.emitter import Emitter
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.events import Event
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.representer import Representer
from org.yaml.snakeyaml.serializer import Serializer
from typing import Any, Callable, Iterable, Tuple


class BukkitYaml(Yaml):

    def __init__(self, constructor: "BaseConstructor", representer: "Representer", dumperOptions: "DumperOptions", loadingConfig: "LoaderOptions"):
        ...


    def serialize(self, node: "Node", output: "Writer") -> None:
        ...



"""
Python module generated from Java source file com.google.common.collect.UnmodifiableSortedMultiset

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.common.collect.Multisets import UnmodifiableMultiset
from java.util import Comparator
from java.util import NavigableSet
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class UnmodifiableSortedMultiset(UnmodifiableMultiset, SortedMultiset):
    """
    Implementation of Multisets.unmodifiableSortedMultiset(SortedMultiset), split out into
    its own file so it can be GWT emulated (to deal with the differing elementSet() types in GWT and
    non-GWT).

    Author(s)
    - Louis Wasserman
    """

    def comparator(self) -> "Comparator"["E"]:
        ...


    def elementSet(self) -> "NavigableSet"["E"]:
        ...


    def descendingMultiset(self) -> "SortedMultiset"["E"]:
        ...


    def firstEntry(self) -> "Entry"["E"]:
        ...


    def lastEntry(self) -> "Entry"["E"]:
        ...


    def pollFirstEntry(self) -> "Entry"["E"]:
        ...


    def pollLastEntry(self) -> "Entry"["E"]:
        ...


    def headMultiset(self, upperBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def subMultiset(self, lowerBound: "E", lowerBoundType: "BoundType", upperBound: "E", upperBoundType: "BoundType") -> "SortedMultiset"["E"]:
        ...


    def tailMultiset(self, lowerBound: "E", boundType: "BoundType") -> "SortedMultiset"["E"]:
        ...



"""
Python module generated from Java source file org.bukkit.block.data.BlockData

Java source file obtained from artifact spigot-api version 1.18.2-R0.1-20220607.160742-53

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit import Server
from org.bukkit import SoundGroup
from org.bukkit.block.data import *
from typing import Any, Callable, Iterable, Tuple


class BlockData(Cloneable):

    def getMaterial(self) -> "Material":
        """
        Get the Material represented by this block data.

        Returns
        - the material
        """
        ...


    def getAsString(self) -> str:
        """
        Gets a string, which when passed into a method such as
        Server.createBlockData(java.lang.String) will unambiguously
        recreate this instance.

        Returns
        - serialized data string for this block
        """
        ...


    def getAsString(self, hideUnspecified: bool) -> str:
        """
        Gets a string, which when passed into a method such as
        Server.createBlockData(java.lang.String) will recreate this or a
        similar instance where unspecified states (if any) may be optionally
        omitted. If this instance was parsed and states are omitted, this exact
        instance will be creatable when parsed again, else their equality cannot
        be guaranteed.
        
        This method will only take effect for BlockData instances created by
        methods such as Server.createBlockData(String) or any similar
        method whereby states are optionally defined. If otherwise, the result of
        .getAsString() will be returned. The following behaviour would be
        expected:
        ````String dataString = "minecraft:chest[waterlogged=True]"
        BlockData data = Bukkit.createBlockData(dataString);
        dataString.equals(data.getAsString(True)); // This would return True
        dataString.equals(data.getAsString(False)); // This would return False as all states are present
        dataString.equals(data.getAsString()); // This is equivalent to the above, "getAsString(False)"````

        Arguments
        - hideUnspecified: True if unspecified states should be omitted,
        False if they are to be shown as performed by .getAsString().

        Returns
        - serialized data string for this block
        """
        ...


    def merge(self, data: "BlockData") -> "BlockData":
        """
        Merges all explicitly set states from the given data with this BlockData.
        
        Note that the given data MUST have been created from one of the String
        parse methods, e.g. Server.createBlockData(java.lang.String) and
        not have been subsequently modified.
        
        Note also that the block types must match identically.

        Arguments
        - data: the data to merge from

        Returns
        - a new instance of this blockdata with the merged data
        """
        ...


    def matches(self, data: "BlockData") -> bool:
        """
        Checks if the specified BlockData matches this block data.
        
        The semantics of this method are such that for manually created or
        modified BlockData it has the same effect as
        Object.equals(java.lang.Object), whilst for parsed data (that to
        which .merge(org.bukkit.block.data.BlockData) applies, it will
        return True when the type and all explicitly set states match.
        
        **Note that these semantics mean that a.matches(b) may not be the same
        as b.matches(a)**

        Arguments
        - data: the data to match against (normally a parsed constant)

        Returns
        - if there is a match
        """
        ...


    def clone(self) -> "BlockData":
        """
        Returns a copy of this BlockData.

        Returns
        - a copy of the block data
        """
        ...


    def getSoundGroup(self) -> "SoundGroup":
        """
        Gets the block's SoundGroup which can be used to get its step
        sound, hit sound, and others.

        Returns
        - the sound effect group
        """
        ...



"""
Python module generated from Java source file com.google.common.base.internal.Finalizer

Java source file obtained from artifact guava version 31.0.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base.internal import *
from java.lang.ref import PhantomReference
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.ref import WeakReference
from java.lang.reflect import Constructor
from java.lang.reflect import Field
from java.lang.reflect import Method
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Finalizer(Runnable):
    """
    Thread that finalizes referents. All references should implement `com.google.common.base.FinalizableReference`.
    
    While this class is public, we consider it to be *internal* and not part of our published API.
    It is public so we can access it reflectively across class loaders in secure environments.
    
    This class can't depend on other Guava code. If we were to load this class in the same class
    loader as the rest of Guava, this thread would keep an indirect strong reference to the class
    loader and prevent it from being garbage collected. This poses a problem for environments where
    you want to throw away the class loader. For example, dynamically reloading a web application or
    unloading an OSGi bundle.
    
    `com.google.common.base.FinalizableReferenceQueue` loads this class in its own class
    loader. That way, this class doesn't prevent the main class loader from getting garbage
    collected, and this class can detect when the main class loader has been garbage collected and
    stop itself.
    """

    @staticmethod
    def startFinalizer(finalizableReferenceClass: type[Any], queue: "ReferenceQueue"["Object"], frqReference: "PhantomReference"["Object"]) -> None:
        """
        Starts the Finalizer thread. FinalizableReferenceQueue calls this method reflectively.

        Arguments
        - finalizableReferenceClass: FinalizableReference.class.
        - queue: a reference queue that the thread will poll.
        - frqReference: a phantom reference to the FinalizableReferenceQueue, which will be queued
            either when the FinalizableReferenceQueue is no longer referenced anywhere, or when its
            close() method is called.
        """
        ...


    def run(self) -> None:
        """
        Loops continuously, pulling references off the queue and cleaning them up.
        """
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.constructor.Constructor

Java source file obtained from artifact snakeyaml version 1.30

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.math import BigDecimal
from java.math import BigInteger
from java.util import Calendar
from java.util import Date
from java.util import UUID
from org.yaml.snakeyaml import LoaderOptions
from org.yaml.snakeyaml import TypeDescription
from org.yaml.snakeyaml.constructor import *
from org.yaml.snakeyaml.error import YAMLException
from org.yaml.snakeyaml.introspector import Property
from org.yaml.snakeyaml.nodes import MappingNode
from org.yaml.snakeyaml.nodes import Node
from org.yaml.snakeyaml.nodes import NodeId
from org.yaml.snakeyaml.nodes import NodeTuple
from org.yaml.snakeyaml.nodes import ScalarNode
from org.yaml.snakeyaml.nodes import SequenceNode
from org.yaml.snakeyaml.nodes import Tag
from org.yaml.snakeyaml.util import EnumUtils
from typing import Any, Callable, Iterable, Tuple


class Constructor(SafeConstructor):
    """
    Construct a custom Java instance.
    """

    def __init__(self):
        ...


    def __init__(self, loadingConfig: "LoaderOptions"):
        ...


    def __init__(self, theRoot: type["Object"]):
        """
        Create Constructor for the specified class as the root.

        Arguments
        - theRoot: - the class (usually JavaBean) to be constructed
        """
        ...


    def __init__(self, theRoot: type["Object"], loadingConfig: "LoaderOptions"):
        ...


    def __init__(self, theRoot: "TypeDescription"):
        ...


    def __init__(self, theRoot: "TypeDescription", loadingConfig: "LoaderOptions"):
        ...


    def __init__(self, theRoot: "TypeDescription", moreTDs: Iterable["TypeDescription"]):
        ...


    def __init__(self, theRoot: "TypeDescription", moreTDs: Iterable["TypeDescription"], loadingConfig: "LoaderOptions"):
        ...


    def __init__(self, theRoot: str):
        """
        Create Constructor for a class which does not have to be in the classpath
        or for a definition from a Spring ApplicationContext.

        Arguments
        - theRoot: fully qualified class name of the root class (usually
                   JavaBean)

        Raises
        - ClassNotFoundException: if cannot be loaded by the classloader
        """
        ...


    def __init__(self, theRoot: str, loadingConfig: "LoaderOptions"):
        ...
